@@ -28,7 +28,7 @@ def get_image_files(md_source):
     image_files = []
     for file in possible_image_files:
         p = file.strip()
-        if p not in image_files and not p.startswith('attachment'):
+        if p not in image_files and not p.startswith('attachment') and not p.startswith('http'):
             image_files.append(p)
     return image_files
 
@@ -45,25 +45,12 @@ class MarkdownPreprocessor(Preprocessor):
     def preprocess_cell(self, cell, resources, cell_index):
         nb_home = Path(resources['metadata']['path'])
         if cell['cell_type'] == 'markdown':
-            all_image_files = get_image_files(cell['source'])
-            # find normal markdown images 
-            for i, image_file in enumerate(all_image_files):
-                if image_file.startswith('http'):
-                    response = requests.get(image_file)
-                    image_data = response.content
-                    ext = '.' + response.headers['Content-Type'].split('/')[-1]
-                else:
-                    image_data = open(nb_home / image_file, 'rb').read()
-                    ext = Path(image_file).suffix
 
-                if ext == '.gif':
-                    from PIL import Image
-                    gif = Image.open(io.BytesIO(image_data))
-                    image_data = io.BytesIO()
-                    gif.save(image_data, 'png')
-                    image_data.seek(0)
-                    image_data = image_data.read()
-                    ext = '.png'
+            # find normal markdown images 
+            all_image_files = get_image_files(cell['source'])
+            for i, image_file in enumerate(all_image_files):
+                image_data = open(nb_home / image_file, 'rb').read()
+                ext = Path(image_file).suffix
                     
                 new_image_name = f'markdown_{cell_index}_normal_image_{i}{ext}'
                 final_image_fn = self.output_dir / new_image_name
@@ -77,21 +64,19 @@ class MarkdownPreprocessor(Preprocessor):
             all_image_tag_files = get_image_tags(cell['source'])
             for i, (entire_tag, src) in enumerate(all_image_tag_files):
                 if src.startswith('http'):
-                    response = requests.get(src)
-                    image_data = response.content
-                    ext = '.' + response.headers['Content-Type'].split('/')[-1]
+                    replace_str = f'![]({src})'
                 else:
                     image_data = open(nb_home / src, 'rb').read()
                     ext = Path(src).suffix
-
-                new_image_name = f'markdown_{cell_index}_html_image_tag_{i}{ext}'
-                final_image_fn = self.output_dir / new_image_name
-                with open(final_image_fn, 'wb') as f:
-                    f.write(image_data)
+                    new_image_name = f'markdown_{cell_index}_html_image_tag_{i}{ext}'
+                    final_image_fn = self.output_dir / new_image_name
+                    with open(final_image_fn, 'wb') as f:
+                        f.write(image_data)
                 
-                image_dir = self.image_dir_name / new_image_name
-                image_dir = urllib.parse.quote(str(image_dir))
-                replace_str = f'![]({image_dir})'
+                    image_dir = self.image_dir_name / new_image_name
+                    image_dir = urllib.parse.quote(str(image_dir))
+                    replace_str = f'![]({image_dir})'
+                    
                 cell['source'] = cell['source'].replace(entire_tag, replace_str)
 
             # find images attached to markdown through dragging and dropping
